@@ -9,7 +9,7 @@ use sqlx::pool::PoolConnection;
 
 /// Projector trait that takes a Postgres transaction in order to create a read model
 #[async_trait]
-pub trait PgProjector<Event: Serialize + DeserializeOwned + Clone + Send + Sync, Error> {
+pub trait PgProjector<Event: Serialize + DeserializeOwned + Send + Sync, Error> {
     /// This function projects one event in each read model that implements this trait.
     /// The result is meant to catch generic errors.
     async fn project(&self, event: &StoreEvent<Event>, connection: &mut PoolConnection<Postgres>) -> Result<(), Error>;
@@ -17,7 +17,7 @@ pub trait PgProjector<Event: Serialize + DeserializeOwned + Clone + Send + Sync,
 
 /// Projector trait that takes a Postgres transaction in order to delete a read model
 #[async_trait]
-pub trait PgProjectorEraser<Event: Serialize + DeserializeOwned + Clone + Send + Sync, Error>:
+pub trait PgProjectorEraser<Event: Serialize + DeserializeOwned + Send + Sync, Error>:
     PgProjector<Event, Error>
 {
     /// Delete the read model entry. It is here because of the eventual need of delete an entire
