@@ -6,7 +6,7 @@ use sqlx::{Pool, Sqlite};
 use crate::esrs::store::StoreEvent;
 
 #[async_trait]
-pub trait SqlitePolicy<Event: Serialize + DeserializeOwned + Clone + Send + Sync, Error> {
+pub trait SqlitePolicy<Event: Serialize + DeserializeOwned + Send + Sync, Error> {
     /// This function intercepts the event and, matching on the type of such event
     /// produces the appropriate side effects.
     /// The result is meant to catch generic errors.
